@@ -5,6 +5,9 @@
 /* Define to 1 if NLS is requested.  */
 #undef ENABLE_NLS
 
+/* The concatenation of the strings "GNU ", and PACKAGE.  */
+#undef GNU_PACKAGE
+
 /* Define as 1 if you have catgets and don't want to use GNU gettext.  */
 #undef HAVE_CATGETS
 
@@ -17,12 +20,12 @@
 /* Define to 1 if you have the stpcpy function.  */
 #undef HAVE_STPCPY
 
+/* Define to rpl_memcmp if the replacement function should be used.  */
+#undef memcmp
+
 /* Define to the name of the distribution.  */
 #undef PACKAGE
 
-/* The concatenation of the strings "GNU ", and PACKAGE.  */
-#undef GNU_PACKAGE
-
 /* Define to 1 if ANSI function prototypes are usable.  */
 #undef PROTOTYPES
 
