@@ -89,21 +89,22 @@ Usage: %s [OPTION] [FILE]...\n\
       printf (_("\
 Concatenate FILE(s), or standard input, to standard output.\n\
 \n\
+  -A, --show-all           equivalent to -vET\n\
   -b, --number-nonblank    number nonblank output lines\n\
   -e                       equivalent to -vE\n\
+  -E, --show-ends          display $ at end of each line\n\
   -n, --number             number all output lines\n\
   -s, --squeeze-blank      never more than one single blank line\n\
   -t                       equivalent to -vT\n\
-  -u                       (ignored)\n\
-  -v, --show-nonprinting   use ^ and M- notation, save for LFD and TAB\n\
-  -A, --show-all           equivalent to -vET\n\
-  -E, --show-ends          display $ at end of each line\n\
   -T, --show-tabs          display TAB characters as ^I\n\
+  -u                       (ignored)\n\
+  -v, --show-nonprinting   use ^ and M- notation, except for LFD and TAB\n\
       --help               display this help and exit\n\
       --version            output version information and exit\n\
 \n\
 With no FILE, or when FILE is -, read standard input.\n\
 "));
+      puts (_("\nReport bugs to textutils-bugs@gnu.ai.mit.edu"));
     }
   exit (status == 0 ? EXIT_SUCCESS : EXIT_FAILURE);
 }
@@ -347,7 +348,8 @@ cat (
 		  if (numbers && numbers_at_empty_lines)
 		    {
 		      next_line_num ();
-		      bpout = (unsigned char *) stpcpy (bpout, line_num_print);
+		      bpout = (unsigned char *) stpcpy ((char *) bpout,
+							line_num_print);
 		    }
 		}
 
@@ -369,7 +371,7 @@ cat (
       if (newlines >= 0 && numbers)
 	{
 	  next_line_num ();
-	  bpout = (unsigned char *) stpcpy (bpout, line_num_print);
+	  bpout = (unsigned char *) stpcpy ((char *) bpout, line_num_print);
 	}
 
       /* Here CH cannot contain a newline character.  */
@@ -579,7 +581,7 @@ main (int argc, char **argv)
 
   if (show_version)
     {
-      printf ("cat - %s\n", PACKAGE_VERSION);
+      printf ("cat (%s) %s\n", GNU_PACKAGE, VERSION);
       exit (EXIT_SUCCESS);
     }
 
