@@ -220,6 +220,7 @@ range, or many ranges separated by commas.  Each range is one of:\n\
 \n\
 With no FILE, or when FILE is -, read standard input.\n\
 "));
+      puts (_("\nReport bugs to textutils-bugs@gnu.ai.mit.edu"));
     }
   exit (status == 0 ? EXIT_SUCCESS : EXIT_FAILURE);
 }
@@ -736,7 +737,7 @@ main (int argc, char **argv)
 
   if (show_version)
     {
-      printf ("cut - %s\n", PACKAGE_VERSION);
+      printf ("cut (%s) %s\n", GNU_PACKAGE, VERSION);
       exit (EXIT_SUCCESS);
     }
 
