@@ -12,9 +12,8 @@
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
- */
+   along with this program; if not, write to the Free Software Foundation,
+   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
 
 /* Written by Ross Paterson <rap@doc.ic.ac.uk>.  */
 
@@ -382,7 +381,7 @@ main (register int argc, register char **argv)
       case 'w':
 	{
 	  long int tmp_long;
-	  if (xstrtol (optarg, NULL, 10, &tmp_long, NULL) != LONGINT_OK
+	  if (xstrtol (optarg, NULL, 10, &tmp_long, "") != LONGINT_OK
 	      || tmp_long <= 0 || tmp_long > INT_MAX)
 	    error (EXIT_FAILURE, 0, _("invalid line number increment: `%s'"),
 		   optarg);
