@@ -12,8 +12,8 @@
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
+   along with this program; if not, write to the Free Software Foundation,
+   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
 
 /* Written by Scott Bartram (nancy!scott@uunet.uu.net)
    Revised by David MacKenzie (djm@gnu.ai.mit.edu) */
@@ -495,7 +495,7 @@ main (int argc, char **argv)
 	case 'v':
 	  {
 	    long int tmp_long;
-	    if (xstrtol (optarg, NULL, 10, &tmp_long, NULL) != LONGINT_OK
+	    if (xstrtol (optarg, NULL, 10, &tmp_long, "") != LONGINT_OK
 		/* Allow it to be negative.  */
 		|| tmp_long > INT_MAX)
 	      error (EXIT_FAILURE, 0, _("invalid starting line number: `%s'"),
@@ -506,7 +506,7 @@ main (int argc, char **argv)
 	case 'i':
 	  {
 	    long int tmp_long;
-	    if (xstrtol (optarg, NULL, 10, &tmp_long, NULL) != LONGINT_OK
+	    if (xstrtol (optarg, NULL, 10, &tmp_long, "") != LONGINT_OK
 		|| tmp_long <= 0 || tmp_long > INT_MAX)
 	      error (EXIT_FAILURE, 0, _("invalid line number increment: `%s'"),
 		     optarg);
@@ -519,7 +519,7 @@ main (int argc, char **argv)
 	case 'l':
 	  {
 	    long int tmp_long;
-	    if (xstrtol (optarg, NULL, 10, &tmp_long, NULL) != LONGINT_OK
+	    if (xstrtol (optarg, NULL, 10, &tmp_long, "") != LONGINT_OK
 		|| tmp_long <= 0 || tmp_long > INT_MAX)
 	      error (EXIT_FAILURE, 0, _("invalid number of blank lines: `%s'"),
 		     optarg);
@@ -532,7 +532,7 @@ main (int argc, char **argv)
 	case 'w':
 	  {
 	    long int tmp_long;
-	    if (xstrtol (optarg, NULL, 10, &tmp_long, NULL) != LONGINT_OK
+	    if (xstrtol (optarg, NULL, 10, &tmp_long, "") != LONGINT_OK
 		|| tmp_long <= 0 || tmp_long > INT_MAX)
 	      error (EXIT_FAILURE, 0,
 		     _("invalid line number field width: `%s'"),
