@@ -425,6 +425,7 @@ With no FILE, or when FILE is -, read standard input.\n\
       --version           output version information and exit\n\
 \n\
 "));
+      puts (_("\nReport bugs to textutils-bugs@gnu.ai.mit.edu"));
     }
   exit (status == 0 ? EXIT_SUCCESS : EXIT_FAILURE);
 }
@@ -472,7 +473,7 @@ main (int argc, char **argv)
 
   if (show_version)
     {
-      printf ("paste - %s\n", PACKAGE_VERSION);
+      printf ("paste (%s) %s\n", GNU_PACKAGE, VERSION);
       exit (EXIT_SUCCESS);
     }
 
