@@ -144,6 +144,7 @@ With no FILE, or when FILE is -, read standard input.\n\
       --help               display this help and exit\n\
       --version            output version information and exit\n\
 "));
+      puts (_("\nReport bugs to textutils-bugs@gnu.ai.mit.edu"));
     }
   exit (status == 0 ? EXIT_SUCCESS : EXIT_FAILURE);
 }
@@ -621,7 +622,7 @@ main (int argc, char **argv)
 
   if (show_version)
     {
-      printf ("tac - %s\n", PACKAGE_VERSION);
+      printf ("tac (%s) %s\n", GNU_PACKAGE, VERSION);
       exit (EXIT_SUCCESS);
     }
 
