@@ -1,5 +1,5 @@
 /* unexpand - convert spaces to tabs
-   Copyright (C) 1989, 1991, 1995 Free Software Foundation, Inc.
+   Copyright (C) 89, 91, 95, 1996 Free Software Foundation, Inc.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -44,7 +44,19 @@
 #include <getopt.h>
 #include <sys/types.h>
 #include "system.h"
-#include "version.h"
+
+#ifdef HAVE_LIMITS_H
+# include <limits.h>
+#endif
+
+#ifndef UINT_MAX
+# define UINT_MAX ((unsigned int) ~(unsigned int) 0)
+#endif
+
+#ifndef INT_MAX
+# define INT_MAX ((int) (UINT_MAX >> 1))
+#endif
+
 #include "error.h"
 
 /* The number of bytes added at a time to the amount of memory
@@ -142,7 +154,7 @@ parse_tabstops (const char *stops)
 	  tabval = tabval * 10 + *stops - '0';
 	}
       else
-	error (1, 0, _("tab size contains an invalid character"));
+	error (EXIT_FAILURE, 0, _("tab size contains an invalid character"));
     }
 
   add_tabstop (tabval);
@@ -160,9 +172,9 @@ validate_tabstops (const int *tabs, int entries)
   for (i = 0; i < entries; i++)
     {
       if (tabs[i] == 0)
-	error (1, 0, _("tab size cannot be 0"));
+	error (EXIT_FAILURE, 0, _("tab size cannot be 0"));
       if (tabs[i] <= prev_tab)
-	error (1, 0, _("tab sizes must be ascending"));
+	error (EXIT_FAILURE, 0, _("tab sizes must be ascending"));
       prev_tab = tabs[i];
     }
 }
@@ -237,14 +249,6 @@ unexpand (void)
   for (;;)
     {
       c = getc (fp);
-      if (c == EOF)
-	{
-	  fp = next_file (fp);
-	  if (fp == NULL)
-	    break;		/* No more files. */
-	  else
-	    continue;
-	}
 
       if (c == ' ' && convert)
 	{
@@ -291,10 +295,10 @@ unexpand (void)
 	    {
 	      if (tab_size == 0)
 		{
-		  /* Do not let tab_index == first_free_tab;
+		  /* Do not let print_tab_index == first_free_tab;
 		     stop when it is 1 less. */
-		  while (tab_index < first_free_tab - 1
-			 && column >= tab_list[tab_index])
+		  while (print_tab_index < first_free_tab - 1
+			 && column >= tab_list[print_tab_index])
 		    print_tab_index++;
 		  next_tab_column = tab_list[print_tab_index];
 		  if (print_tab_index < first_free_tab - 1)
@@ -322,6 +326,15 @@ unexpand (void)
 		}
 	    }
 
+	  if (c == EOF)
+	    {
+	      fp = next_file (fp);
+	      if (fp == NULL)
+		break;		/* No more files. */
+	      else
+		continue;
+	    }
+
 	  if (convert)
 	    {
 	      if (c == '\b')
@@ -373,22 +386,27 @@ With no FILE, or when FILE is -, read standard input.\n\
 \n\
 Instead of -t NUMBER or -t LIST, -NUMBER or -LIST may be used.\n\
 "));
+      puts (_("\nReport bugs to textutils-bugs@gnu.ai.mit.edu"));
     }
-  exit (status);
+  exit (status == 0 ? EXIT_SUCCESS : EXIT_FAILURE);
 }
 
-void
+int
 main (int argc, char **argv)
 {
   int tabval = -1;		/* Value of tabstop being read, or -1. */
   int c;			/* Option character. */
 
+  program_name = argv[0];
+  setlocale (LC_ALL, "");
+  bindtextdomain (PACKAGE, LOCALEDIR);
+  textdomain (PACKAGE);
+
   have_read_stdin = 0;
   exit_status = 0;
   convert_entire_line = 0;
   tab_list = NULL;
   first_free_tab = 0;
-  program_name = argv[0];
 
   while ((c = getopt_long (argc, argv, "at:,0123456789", longopts, (int *) 0))
 	 != EOF)
@@ -421,8 +439,8 @@ main (int argc, char **argv)
 
   if (show_version)
     {
-      printf ("unexpand - %s\n", version_string);
-      exit (0);
+      printf ("unexpand (%s) %s\n", GNU_PACKAGE, VERSION);
+      exit (EXIT_SUCCESS);
     }
 
   if (show_help)
@@ -437,7 +455,11 @@ main (int argc, char **argv)
   else if (first_free_tab == 1)
     tab_size = tab_list[0];
   else
-    tab_size = 0;
+    {
+      /* Append a sentinel to the list of tab stop indices.  */
+      add_tabstop (INT_MAX);
+      tab_size = 0;
+    }
 
   if (optind == argc)
     file_list = stdin_argv;
@@ -447,8 +469,8 @@ main (int argc, char **argv)
   unexpand ();
 
   if (have_read_stdin && fclose (stdin) == EOF)
-    error (1, errno, "-");
+    error (EXIT_FAILURE, errno, "-");
   if (fclose (stdout) == EOF)
-    error (1, errno, _("write error"));
-  exit (exit_status);
+    error (EXIT_FAILURE, errno, _("write error"));
+  exit (exit_status == 0 ? EXIT_SUCCESS : EXIT_FAILURE);
 }
