@@ -79,12 +79,13 @@ Usage: %s [OPTION]... [FILE]...\n\
 Print line, word, and byte counts for each FILE, and a total line if\n\
 more than one FILE is specified.  With no FILE, or when FILE is -,\n\
 read standard input.\n\
+  -c, --bytes, --chars   print the byte counts\n\
   -l, --lines            print the newline counts\n\
   -w, --words            print the word counts\n\
-  -c, --bytes, --chars   print the byte counts\n\
       --help             display this help and exit\n\
       --version          output version information and exit\n\
 "));
+      puts (_("\nReport bugs to textutils-bugs@gnu.ai.mit.edu"));
     }
   exit (status == 0 ? EXIT_SUCCESS : EXIT_FAILURE);
 }
@@ -292,7 +293,7 @@ main (int argc, char **argv)
 
   if (show_version)
     {
-      printf ("wc - %s\n", PACKAGE_VERSION);
+      printf ("wc (%s) %s\n", GNU_PACKAGE, VERSION);
       exit (EXIT_SUCCESS);
     }
 
